==> kui-web-terminal-container-v2.1.13-3.tar.gz: package/mdist/lib/view/css-for-value.d.ts <==
import TrafficLight from '../model/traffic-light';
declare const _default: {
    UNKNOWN: string;
    DEPLOYED: TrafficLight;
    DELETED: string;
    SUPERSEDED: TrafficLight;
    FAILED: TrafficLight;
    DELETING: TrafficLight;
    Offline: TrafficLight;
    'Init:0/1': TrafficLight;
    PodScheduled: TrafficLight;
    PodInitializing: TrafficLight;
    Initialized: TrafficLight;
    Terminating: TrafficLight;
    ImagePullBackOff: TrafficLight;
    ErrImagePull: TrafficLight;
    Error: TrafficLight;
    CrashLoopBackOff: TrafficLight;
    Failed: TrafficLight;
    PropagationFailed: TrafficLight;
    Fail: TrafficLight;
    Running: TrafficLight;
    Pending: TrafficLight;
    Succeeded: TrafficLight;
    Completed: TrafficLight;
    Unknown: string;
    Propagated: TrafficLight;
    Subscribed: TrafficLight;
    Ready: TrafficLight;
    ProvisionedSuccessfully: TrafficLight;
    Active: TrafficLight;
    Online: TrafficLight;
    NodeReady: TrafficLight;
    Pulled: TrafficLight;
    Rebooted: TrafficLight;
    Started: TrafficLight;
    Created: TrafficLight;
    Scheduled: TrafficLight;
    SuccessfulCreate: TrafficLight;
    SuccessfulMountVol: TrafficLight;
    ContainerCreating: TrafficLight;
    Starting: TrafficLight;
    NodeNotReady: TrafficLight;
    Killing: TrafficLight;
    Deleting: TrafficLight;
    Pulling: TrafficLight;
    BackOff: TrafficLight;
    Unhealthy: TrafficLight;
    FailedScheduling: TrafficLight;
    FailedKillPod: TrafficLight;
};
/**
 * Decorate certain values specially
 *
 */
export default _default;

==> kui-web-terminal-container-v2.3.3-6.tar.gz: package/mdist/lib/view/css-for-value.d.ts <==
import TrafficLight from '../model/traffic-light';
declare const _default: {
    UNKNOWN: string;
    DEPLOYED: TrafficLight;
    DELETED: string;
    SUPERSEDED: TrafficLight;
    FAILED: TrafficLight;
    DELETING: TrafficLight;
    Offline: TrafficLight;
    'Init:0/1': TrafficLight;
    PodScheduled: TrafficLight;
    PodInitializing: TrafficLight;
    Initialized: TrafficLight;
    Terminating: TrafficLight;
    ImagePullBackOff: TrafficLight;
    ErrImagePull: TrafficLight;
    Error: TrafficLight;
    UnexpectedAdmissionError: TrafficLight;
    OOMKilled: TrafficLight;
    1: TrafficLight;
    0: TrafficLight;
    '<none>': TrafficLight;
    CrashLoopBackOff: TrafficLight;
    Failed: TrafficLight;
    PropagationFailed: TrafficLight;
    Fail: TrafficLight;
    Running: TrafficLight;
    Pending: TrafficLight;
    Succeeded: TrafficLight;
    Completed: TrafficLight;
    Unknown: string;
    Propagated: TrafficLight;
    Subscribed: TrafficLight;
    Ready: TrafficLight;
    ProvisionedSuccessfully: TrafficLight;
    Active: TrafficLight;
    Online: TrafficLight;
    NodeReady: TrafficLight;
    Pulled: TrafficLight;
    Rebooted: TrafficLight;
    Started: TrafficLight;
    Created: TrafficLight;
    Scheduled: TrafficLight;
    SuccessfulCreate: TrafficLight;
    SuccessfulMountVol: TrafficLight;
    ContainerCreating: TrafficLight;
    Starting: TrafficLight;
    NodeNotReady: TrafficLight;
    Killing: TrafficLight;
    Deleting: TrafficLight;
    Pulling: TrafficLight;
    BackOff: TrafficLight;
    Unhealthy: TrafficLight;
    FailedScheduling: TrafficLight;
    FailedKillPod: TrafficLight;
};
/**
 * Decorate certain values specially
 *
 */
export default _default;
